<?php

/*
 * Plugin Name: iPay88 Online Credit Payment
 * Plugin URI: https://docs.ipay88.co.id/woocommerce
 * Description: Allows you to use iPay88 Online Credit Payment with the WooCommerce plugin.
 * Version:  1.5.2
 * Author: iPay88 Indonesia
 * Author URI: https://www.ipay88.co.id/
 * Text Domain: hhttps://www.ipay88.co.id/
 * License: The MIT License (MIT)
 *
 */

defined('ABSPATH') or exit();

define('IPAY88_ONLINE_CREDIT_TEXT_DOMAIN', 'ipay88-online-credit-for-woocommerce');
define('IPAY88_ONLINE_CREDIT_DEFAULT_SUCCESS_PINGBACK_VALUE', 'OK');
define('IPAY88_ONLINE_CREDIT_ORDER_STATUS_PENDING', 'wc-pending');
define('IPAY88_ONLINE_CREDIT_ORDER_STATUS_COMPLETED', 'wc-completed');
define('IPAY88_ONLINE_CREDIT_ORDER_STATUS_PROCESSING', 'wc-processing');
define('IPAY88_ONLINE_CREDIT_PLUGIN_PATH', plugin_dir_path(__FILE__));
define('IPAY88_ONLINE_CREDIT_PLUGIN_URL', plugins_url('', __FILE__));

function load_ipay88_online_credit_payments()
{
	if (!class_exists('WC_Payment_Gateway')) return; // Nothing happens here is WooCommerce is not loaded

	include(IPAY88_ONLINE_CREDIT_PLUGIN_PATH . '/lib/ipay88-online-credit-php/Autoload.php');
	include(IPAY88_ONLINE_CREDIT_PLUGIN_PATH . '/includes/class-ipay88-online-credit-abstract.php');
	include(IPAY88_ONLINE_CREDIT_PLUGIN_PATH . '/includes/class-ipay88-online-credit-gateway.php');

	function ipay88_online_credit_payments($methods)
	{
		$methods[] = 'ipay88_online_credit_Gateway';
		return $methods;
	}

	add_filter('woocommerce_payment_gateways', 'ipay88_online_credit_payments');
}

add_action('plugins_loaded', 'load_ipay88_online_credit_payments', 0);

/**
 * Add ipay88_online_credit Scripts
 */
function ipay88_online_credit_scripts()
{
	wp_register_script('placeholder', IPAY88_ONLINE_CREDIT_PLUGIN_URL . '/assets/js/payment.js', array('jquery'), '1', true);
	wp_enqueue_script('placeholder');
}

add_action('wp_enqueue_scripts', 'ipay88_online_credit_scripts');

/**
 * Require the woocommerce plugin installed first
 */
function ipay88_online_credit_child_plugin_notice()
{ ?>
	<div class="error">
		<p><?php echo __("Sorry, but iPay88 Online Credit Payment Plugin requires the Woocommerce plugin to be installed and active.", IPAY88_ONLINE_CREDIT_TEXT_DOMAIN) ?></p>
	</div>
<?php
}

function ipay88_online_credit_child_plugin_has_parent_plugin()
{
	if (is_admin() && current_user_can('activate_plugins') && !is_plugin_active('woocommerce/woocommerce.php')) {
		add_action('admin_notices', 'pw_child_plugin_notice');

		deactivate_plugins(plugin_basename(__FILE__));
		if (isset($_GET['activate'])) {
			unset($_GET['activate']);
		}
	}
}

add_action('admin_init', 'ipay88_online_credit_child_plugin_has_parent_plugin');

/**
 * Adds plugin page links
 *
 * @since 1.0.0
 * @param array $links all plugin links
 * @return array $links all plugin links + our custom links (i.e., "Settings")
 */
function wc_ipay88_online_credit_gateway_plugin_links($links)
{
	$plugin_links = array(
		'<a href="' . admin_url('admin.php?page=wc-settings&tab=checkout&section=ipay88_online_credit') . '">' . __('Setting', 'ipay88_online_credit') . '</a>'
	);
	return array_merge($plugin_links, $links);
}

class WC_iPay88_online_credit
{
	/**
	 * WC Logger object
	 * @var object
	 */
	private static $log;

	/**
	 * Plugin URL
	 * @var type
	 */
	private static $plugin_url;

	/**
	 * Plugin Path
	 * @var string
	 */
	private static $plugin_path;

	public function __construct()
	{

		// Add required files
		add_action('woocommerce_init', array($this, 'load_gateway_files'), 15);

		add_action('init', array($this, 'load_text_domain'));

		add_filter('woocommerce_payment_gateways', array($this, 'add_ipay88_gateway'));

		// Add a 'Settings' link to the plugin action links
		//add_filter('plugin_action_links_' . plugin_basename(__FILE__), array($this, 'settings_support_link'), 10, 4);

		add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'wc_ipay88_online_credit_gateway_plugin_links');
	}

	/**
	 * Localisation
	 **/
	public function load_text_domain()
	{
		// Use the string for text domain. WPML does not pick it up, if a variable is used
		load_plugin_textdomain(IPAY88_ONLINE_CREDIT_TEXT_DOMAIN, false, self::plugin_path() . '/languages/');
	}

	/**
	 * Add 'Settings' link to the plugin actions links
	 *
	 * @since 1.1
	 * @return array associative array of plugin action links
	 */
	public function settings_support_link($actions, $plugin_file, $plugin_data, $context)
	{

		$gateway = $this->get_gateway_class();

		return array_merge(
			array('settings' => '<a href="' . WC_Compat_iPay88_online_credit::gateway_settings_page($gateway) . '">' . __('Settings', IPAY88_ONLINE_CREDIT_TEXT_DOMAIN) . '</a>'),
			$actions
		);
	}

	/**
	 * Get the correct gateway class name to load
	 *
	 * @since 1.1
	 * @return string Class name
	 */
	private function get_gateway_class()
	{
		return 'WC_Gateway_iPay88_online_credit';
	}

	/**
	 * Load gateway files
	 *
	 * @since 1.1
	 */
	public function load_gateway_files()
	{

		include_once('includes/class-ipay88-online-credit-abstract.php');
		include_once('includes/class-ipay88-online-credit-compat.php');
		include_once('includes/class-ipay88-online-credit-gateway.php');
	}

	/**
	 * Savely get POST variables
	 *
	 * @since 1.1
	 * @param string $name POST variable name
	 * @return string The variable value
	 */
	public static function get_post($name)
	{
		if (isset($_POST[$name])) {
			return $_POST[$name];
		}
		return null;
	}

	/**
	 * Savely get GET variables
	 *
	 * @since 1.1
	 * @param string $name GET variable name
	 * @return string The variable value
	 */
	public static function get_get($name)
	{
		if (isset($_GET[$name])) {
			return $_GET[$name];
		}
		return null;
	}

	/**
	 * Add the gateway to WooCommerce
	 *
	 * @since 1.1
	 * @param array $methods
	 * @return array
	 */
	function add_ipay88_gateway($methods)
	{
		$methods[] = $this->get_gateway_class();

		return $methods;
	}

	/**
	 * Add debug log message
	 *
	 * @since 1.1
	 * @param string $message
	 */
	public static function add_debug_log($message)
	{
		/*
		if (!is_object(self::$log)) {
			self::$log = WC_Compat_iPay88_online_credit::get_wc_logger();
		}
		self::$log->add('ipay88', $message);
		
		$log = new WC_Logger();
		$log_entry = print_r( $e, true );
		$log_entry .= 'Exception Trace: ' . print_r( $e->getTraceAsString(), true );
		$log->add( 'new-woocommerce-log-name', $log_entry );
		*/
		
		$log = new WC_Logger();
		$log_entry = print_r( $message, true );
		$log->add( 'WC_iPay88_online_credit', $log_entry );
		
	}

	/**
	 * Get the plugin url
	 *
	 * @since 1.1
	 * @return string
	 */
	public static function plugin_url() 
	{
		if ( self::$plugin_url ) 
		{
			return self::$plugin_url;
		}

		return self::$plugin_url = untrailingslashit( plugins_url( '/', __FILE__ ) );
	}

	/**
	 * Get the plugin path
	 *
	 * @since 1.1
	 * @return string
	 */
	public static function plugin_path()
	{
		if (self::$plugin_path) {
			return self::$plugin_path;
		}

		return self::$plugin_path = untrailingslashit(plugin_dir_path(__FILE__));
	}
}
new WC_iPay88_online_credit();
